#[repr(transparent)]pub struct Reg1(pub u32);Expand description
DCDC Register 1
Tuple Fields
0: u32Implementations
Sourceimpl Reg1
impl Reg1
Sourcepub const fn reg_fbk_sel(&self) -> RegFbkSel
pub const fn reg_fbk_sel(&self) -> RegFbkSel
Select the feedback point of the internal regulator
Sourcepub const fn set_reg_fbk_sel(&mut self, val: RegFbkSel)
pub const fn set_reg_fbk_sel(&mut self, val: RegFbkSel)
Select the feedback point of the internal regulator
Sourcepub const fn reg_rload_sw(&self) -> RegRloadSw
pub const fn reg_rload_sw(&self) -> RegRloadSw
This controls the load resistor of the internal regulator of DCDC
Sourcepub const fn set_reg_rload_sw(&mut self, val: RegRloadSw)
pub const fn set_reg_rload_sw(&mut self, val: RegRloadSw)
This controls the load resistor of the internal regulator of DCDC
Sourcepub const fn lp_cmp_isrc_sel(&self) -> LpCmpIsrcSel
pub const fn lp_cmp_isrc_sel(&self) -> LpCmpIsrcSel
Low Power Comparator Current Bias
Sourcepub const fn set_lp_cmp_isrc_sel(&mut self, val: LpCmpIsrcSel)
pub const fn set_lp_cmp_isrc_sel(&mut self, val: LpCmpIsrcSel)
Low Power Comparator Current Bias
Sourcepub const fn loopctrl_hst_thresh(&self) -> LoopctrlHstThresh
pub const fn loopctrl_hst_thresh(&self) -> LoopctrlHstThresh
Increase Threshold Detection
Sourcepub const fn set_loopctrl_hst_thresh(&mut self, val: LoopctrlHstThresh)
pub const fn set_loopctrl_hst_thresh(&mut self, val: LoopctrlHstThresh)
Increase Threshold Detection
Sourcepub const fn loopctrl_en_hyst(&self) -> bool
pub const fn loopctrl_en_hyst(&self) -> bool
Enable Hysteresis
Sourcepub const fn set_loopctrl_en_hyst(&mut self, val: bool)
pub const fn set_loopctrl_en_hyst(&mut self, val: bool)
Enable Hysteresis
Sourcepub const fn set_vbg_trim(&mut self, val: u8)
pub const fn set_vbg_trim(&mut self, val: u8)
Trim Bandgap Voltage